Method: RestClient.proxy_set?
- Defined in:
- lib/restclient.rb
.proxy_set? ⇒ Boolean
Return whether RestClient.proxy was set explicitly. We use this to differentiate between no value being set and a value explicitly set to nil.
109 110 111 |
# File 'lib/restclient.rb', line 109 def self.proxy_set? @proxy_set ||= false end |