Class: RestClient::Request
- Inherits:
-
Object
- Object
- RestClient::Request
- Defined in:
- lib/restclient/request.rb,
lib/restclient/exceptions.rb
Overview
backwards compatibility
Constant Summary
- Redirect =
RestClient::Redirect
RestClient::Unauthorized
- RequestFailed =
RestClient::RequestFailed
Instance Attribute Summary (collapse)
-
- (Object) args
readonly
Returns the value of attribute args.
-
- (Object) cookies
readonly
Returns the value of attribute cookies.
-
- (Object) headers
readonly
Returns the value of attribute headers.
-
- (Object) max_redirects
readonly
Returns the value of attribute max_redirects.
-
- (Object) method
readonly
Returns the value of attribute method.
-
- (Object) open_timeout
readonly
Returns the value of attribute open_timeout.
-
- (Object) password
readonly
Returns the value of attribute password.
-
- (Object) payload
readonly
Returns the value of attribute payload.
-
- (Object) processed_headers
readonly
Returns the value of attribute processed_headers.
-
- (Object) raw_response
readonly
Returns the value of attribute raw_response.
-
- (Object) ssl_ca_file
readonly
Returns the value of attribute ssl_ca_file.
-
- (Object) ssl_client_cert
readonly
Returns the value of attribute ssl_client_cert.
-
- (Object) ssl_client_key
readonly
Returns the value of attribute ssl_client_key.
-
- (Object) timeout
readonly
Returns the value of attribute timeout.
-
- (Object) url
readonly
Returns the value of attribute url.
-
- (Object) user
readonly
Returns the value of attribute user.
-
- (Object) verify_ssl
readonly
Returns the value of attribute verify_ssl.
Class Method Summary (collapse)
Instance Method Summary (collapse)
- - (Object) default_headers
- - (Object) execute(&block)
- - (Object) fetch_body(http_response)
-
- (Request) initialize(args)
constructor
A new instance of Request.
- - (Object) log_request
- - (Object) log_response(res)
- - (Object) make_headers(user_headers)
- - (Object) net_http_class
- - (Object) net_http_request_class(method)
- - (Object) parse_url(url)
- - (Object) parse_url_with_auth(url)
- - (Object) process_payload(p = nil, parent_key = nil)
- - (Object) process_result(res, &block)
-
- (Object) process_url_params(url, headers)
Extract the query parameters and append them to the url.
- - (Object) setup_credentials(req)
-
- (Object) stringify_headers(headers)
Return a hash of headers whose keys are capitalized strings.
- - (Object) transmit(uri, req, payload, &block)
Constructor Details
- (Request) initialize(args)
A new instance of Request
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/restclient/request.rb', line 36 def initialize args @method = args[:method] or raise ArgumentError, "must pass :method" @headers = args[:headers] || {} if args[:url] @url = process_url_params(args[:url], headers) else raise ArgumentError, "must pass :url" end @cookies = @headers.delete(:cookies) || args[:cookies] || {} @payload = Payload.generate(args[:payload]) @user = args[:user] @password = args[:password] @timeout = args[:timeout] @open_timeout = args[:open_timeout] @block_response = args[:block_response] @raw_response = args[:raw_response] || false @verify_ssl = args[:verify_ssl] || false @ssl_client_cert = args[:ssl_client_cert] || nil @ssl_client_key = args[:ssl_client_key] || nil @ssl_ca_file = args[:ssl_ca_file] || nil @tf = nil # If you are a raw request, this is your tempfile @max_redirects = args[:max_redirects] || 10 @processed_headers = make_headers headers @args = args end |
Instance Attribute Details
- (Object) args (readonly)
Returns the value of attribute args
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def args @args end |
- (Object) cookies (readonly)
Returns the value of attribute cookies
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def @cookies end |
- (Object) headers (readonly)
Returns the value of attribute headers
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def headers @headers end |
- (Object) max_redirects (readonly)
Returns the value of attribute max_redirects
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def max_redirects @max_redirects end |
- (Object) method (readonly)
Returns the value of attribute method
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def method @method end |
- (Object) open_timeout (readonly)
Returns the value of attribute open_timeout
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def open_timeout @open_timeout end |
- (Object) password (readonly)
Returns the value of attribute password
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def password @password end |
- (Object) payload (readonly)
Returns the value of attribute payload
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def payload @payload end |
- (Object) processed_headers (readonly)
Returns the value of attribute processed_headers
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def processed_headers @processed_headers end |
- (Object) raw_response (readonly)
Returns the value of attribute raw_response
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def raw_response @raw_response end |
- (Object) ssl_ca_file (readonly)
Returns the value of attribute ssl_ca_file
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def ssl_ca_file @ssl_ca_file end |
- (Object) ssl_client_cert (readonly)
Returns the value of attribute ssl_client_cert
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def ssl_client_cert @ssl_client_cert end |
- (Object) ssl_client_key (readonly)
Returns the value of attribute ssl_client_key
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def ssl_client_key @ssl_client_key end |
- (Object) timeout (readonly)
Returns the value of attribute timeout
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def timeout @timeout end |
- (Object) url (readonly)
Returns the value of attribute url
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def url @url end |
- (Object) user (readonly)
Returns the value of attribute user
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def user @user end |
- (Object) verify_ssl (readonly)
Returns the value of attribute verify_ssl
27 28 29 |
# File 'lib/restclient/request.rb', line 27 def verify_ssl @verify_ssl end |
Class Method Details
+ (Object) decode(content_encoding, body)
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/restclient/request.rb', line 235 def self.decode content_encoding, body if (!body) || body.empty? body elsif content_encoding == 'gzip' Zlib::GzipReader.new(StringIO.new(body)).read elsif content_encoding == 'deflate' begin Zlib::Inflate.new.inflate body rescue Zlib::DataError # No luck with Zlib decompression. Let's try with raw deflate, # like some broken web servers do. Zlib::Inflate.new(-Zlib::MAX_WBITS).inflate body end else body end end |
+ (Object) execute(args, &block)
32 33 34 |
# File 'lib/restclient/request.rb', line 32 def self.execute(args, & block) new(args).execute(& block) end |
Instance Method Details
- (Object) default_headers
294 295 296 |
# File 'lib/restclient/request.rb', line 294 def default_headers {:accept => '*/*; q=0.5, application/xml', :accept_encoding => 'gzip, deflate'} end |
- (Object) execute(&block)
62 63 64 65 66 67 |
# File 'lib/restclient/request.rb', line 62 def execute & block uri = parse_url_with_auth(url) transmit uri, net_http_request_class(method).new(uri.request_uri, processed_headers), payload, & block ensure payload.close if payload end |
- (Object) fetch_body(http_response)
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/restclient/request.rb', line 191 def fetch_body(http_response) if @raw_response # Taken from Chef, which as in turn... # Stolen from http://www.ruby-forum.com/topic/166423 # Kudos to _why! @tf = Tempfile.new("rest-client") size, total = 0, http_response.header['Content-Length'].to_i http_response.read_body do |chunk| @tf.write chunk size += chunk.size if RestClient.log if size == 0 RestClient.log << "#{@method} #{@url} done (0 length file\n)" elsif total == 0 RestClient.log << "#{@method} #{@url} (zero content length)\n" else RestClient.log << "#{@method} #{@url} %d%% done (%d of %d)\n" % [(size * 100) / total, size, total] end end end @tf.close @tf else http_response.read_body end http_response end |
- (Object) log_request
253 254 255 256 257 258 259 260 261 |
# File 'lib/restclient/request.rb', line 253 def log_request if RestClient.log out = [] out << "RestClient.#{method} #{url.inspect}" out << payload.short_inspect if payload out << processed_headers.to_a.sort.map { |(k, v)| [k.inspect, v.inspect].join("=>") }.join(", ") RestClient.log << out.join(', ') + "\n" end end |
- (Object) log_response(res)
263 264 265 266 267 268 |
# File 'lib/restclient/request.rb', line 263 def log_response res if RestClient.log size = @raw_response ? File.size(@tf.path) : (res.body.nil? ? 0 : res.body.size) RestClient.log << "# => #{res.code} #{res.class.to_s.gsub(/^Net::HTTP/, '')} | #{(res['Content-type'] || '').gsub(/;.*$/, '')} #{size} bytes\n" end end |
- (Object) make_headers(user_headers)
88 89 90 91 92 93 94 95 |
# File 'lib/restclient/request.rb', line 88 def make_headers user_headers unless @cookies.empty? user_headers[:cookie] = @cookies.map { |(key, val)| "#{key.to_s}=#{CGI::unescape(val)}" }.sort.join('; ') end headers = stringify_headers(default_headers).merge(stringify_headers(user_headers)) headers.merge!(@payload.headers) if @payload headers end |
- (Object) net_http_class
97 98 99 100 101 102 103 104 |
# File 'lib/restclient/request.rb', line 97 def net_http_class if RestClient.proxy proxy_uri = URI.parse(RestClient.proxy) Net::HTTP::Proxy(proxy_uri.host, proxy_uri.port, proxy_uri.user, proxy_uri.password) else Net::HTTP end end |
- (Object) net_http_request_class(method)
106 107 108 |
# File 'lib/restclient/request.rb', line 106 def net_http_request_class(method) Net::HTTP.const_get(method.to_s.capitalize) end |
- (Object) parse_url(url)
110 111 112 113 |
# File 'lib/restclient/request.rb', line 110 def parse_url(url) url = "http://#{url}" unless url.match(/^http/) URI.parse(url) end |
- (Object) parse_url_with_auth(url)
115 116 117 118 119 120 |
# File 'lib/restclient/request.rb', line 115 def parse_url_with_auth(url) uri = parse_url(url) @user = CGI.unescape(uri.user) if uri.user @password = CGI.unescape(uri.password) if uri.password uri end |
- (Object) process_payload(p = nil, parent_key = nil)
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/restclient/request.rb', line 122 def process_payload(p=nil, parent_key=nil) unless p.is_a?(Hash) p else @headers[:content_type] ||= 'application/x-www-form-urlencoded' p.keys.map do |k| key = parent_key ? "#{parent_key}[#{k}]" : k if p[k].is_a? Hash process_payload(p[k], key) else value = URI.escape(p[k].to_s, Regexp.new("[^#{URI::PATTERN::UNRESERVED}]")) "#{key}=#{value}" end end.join("&") end end |
- (Object) process_result(res, &block)
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/restclient/request.rb', line 219 def process_result res, & block if @raw_response # We don't decode raw requests response = RawResponse.new(@tf, res, args) else response = Response.create(Request.decode(res['content-encoding'], res.body), res, args) end if block_given? block.call(response, self, res, & block) else response.return!(self, res, & block) end end |
- (Object) process_url_params(url, headers)
Extract the query parameters and append them to the url
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/restclient/request.rb', line 70 def process_url_params url, headers url_params = {} headers.delete_if do |key, value| if 'params' == key.to_s.downcase && value.is_a?(Hash) url_params.merge! value true else false end end unless url_params.empty? query_string = url_params.collect { |k, v| "#{k.to_s}=#{CGI::escape(v.to_s)}" }.join('&') url + "?#{query_string}" else url end end |
- (Object) setup_credentials(req)
187 188 189 |
# File 'lib/restclient/request.rb', line 187 def setup_credentials(req) req.basic_auth(user, password) if user end |
- (Object) stringify_headers(headers)
Return a hash of headers whose keys are capitalized strings
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/restclient/request.rb', line 271 def stringify_headers headers headers.inject({}) do |result, (key, value)| if key.is_a? Symbol key = key.to_s.split(/_/).map { |w| w.capitalize }.join('-') end if 'CONTENT-TYPE' == key.upcase target_value = value.to_s result[key] = MIME::Types.type_for_extension target_value elsif 'ACCEPT' == key.upcase # Accept can be composed of several comma-separated values if value.is_a? Array target_values = value else target_values = value.to_s.split ',' end result[key] = target_values.map { |ext| MIME::Types.type_for_extension(ext.to_s.strip) }.join(', ') else result[key] = value.to_s end result end end |
- (Object) transmit(uri, req, payload, &block)
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/restclient/request.rb', line 139 def transmit uri, req, payload, & block setup_credentials req net = net_http_class.new(uri.host, uri.port) net.use_ssl = uri.is_a?(URI::HTTPS) if (@verify_ssl == false) || (@verify_ssl == OpenSSL::SSL::VERIFY_NONE) net.verify_mode = OpenSSL::SSL::VERIFY_NONE elsif @verify_ssl.is_a? Integer net.verify_mode = @verify_ssl net.verify_callback = lambda do |preverify_ok, ssl_context| if (!preverify_ok) || ssl_context.error != 0 err_msg = "SSL Verification failed -- Preverify: #{preverify_ok}, Error: #{ssl_context.error_string} (#{ssl_context.error})" raise SSLCertificateNotVerified.new(err_msg) end true end end net.cert = @ssl_client_cert if @ssl_client_cert net.key = @ssl_client_key if @ssl_client_key net.ca_file = @ssl_ca_file if @ssl_ca_file net.read_timeout = @timeout if @timeout net.open_timeout = @open_timeout if @open_timeout # disable the timeout if the timeout value is -1 net.read_timeout = nil if @timeout == -1 net.out_timeout = nil if @open_timeout == -1 RestClient.before_execution_procs.each do |before_proc| before_proc.call(req, args) end log_request net.start do |http| if @block_response http.request(req, payload ? payload.to_s : nil, & @block_response) else res = http.request(req, payload ? payload.to_s : nil) { |http_response| fetch_body(http_response) } log_response res process_result res, & block end end rescue EOFError raise RestClient::ServerBrokeConnection rescue Timeout::Error raise RestClient::RequestTimeout end |